@@ -14,8 +14,20 @@
   }
 }
 
-random_port <- function(from = 49152L, to = 65355L) {
-  sample(seq.int(from = from, to = to, by = 1L), size = 1L)
+stop0 <- function(...) {
+  stop(..., call. = FALSE)
+}
+
+trn <- function(condition, x, y) {
+  if (condition) {
+    x
+  } else {
+    y
+  }
+}
+
+warn0 <- function(...) {
+  warning(..., call. = FALSE)
 }
 
 with_safe_path <- function(path, code) {
