@@ -1,6 +1,6 @@
 test_that("serve_pprof()", {
   skip("interactive only")
-  pprof <- record_pprof(replicate(1e2, sample.int(1e4)))
+  pprof <- record_pprof(slow_function())
   # Should launch a browser and not show a message.
   px <- serve_pprof(pprof, browse = TRUE, verbose = FALSE)
   px$kill()
@@ -11,7 +11,7 @@ test_that("serve_pprof()", {
 
 test_that("serve_rprof()", {
   skip("interactive only")
-  rprof <- record_rprof(replicate(1e2, sample.int(1e4)))
+  rprof <- record_rprof(slow_function())
   # Should launch a browser and not show a message.
   px <- serve_rprof(rprof, browse = TRUE, verbose = FALSE)
   px$kill()
@@ -24,14 +24,14 @@ test_that("pprof()", {
   skip("interactive only")
   # Should launch a browser and not show a message.
   px <- pprof(
-    replicate(1e2, sample.int(1e4)),
+    slow_function(),
     browse = TRUE,
     verbose = FALSE
   )
   px$kill()
   # Should show a message but not launch a browser.
   px <- pprof(
-    replicate(1e2, sample.int(1e4)),
+    slow_function(),
     browse = FALSE,
     verbose = TRUE
   )
