@@ -17,6 +17,11 @@ test_that("random_port()", {
   expect_equal(length(port), 1L)
 })
 
+test_that("trn()", {
+  expect_equal(trn(TRUE, "a", "b"), "a")
+  expect_equal(trn(FALSE, "a", "b"), "b")
+})
+
 test_that("with_safe_path(), nonempty case", {
   hash <- "46f6ded6b2f73c352be884dae6317700"
   bin <- paste0(
@@ -39,3 +44,11 @@ test_that("with_safe_path(), empty case", {
   px <- with_safe_path("", processx::run(bin, c("getenv", "PATH")))
   expect_false(grepl("^:", px$stdout))
 })
+
+test_that("stop0()", {
+  expect_error(stop0(123))
+})
+
+test_that("warn0()", {
+  expect_warning(warn0(123))
+})
